==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/EntityRiskPolicyRuleActionTerminateAllSessions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EntityRiskPolicyRuleActionTerminateAllSessions
 */
@JsonPropertyOrder({ EntityRiskPolicyRuleActionTerminateAllSessions.JSON_PROPERTY_ACTION })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EntityRiskPolicyRuleActionTerminateAllSessions implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * This action revokes or terminates all of the user&#39;s active sessions.
     */
    public enum ActionEnum {
        TERMINATE_ALL_SESSIONS("TERMINATE_ALL_SESSIONS"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        ActionEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static ActionEnum fromValue(String value) {
            for (ActionEnum b : ActionEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ACTION = "action";
    private ActionEnum action;

    public EntityRiskPolicyRuleActionTerminateAllSessions() {
    }

    public EntityRiskPolicyRuleActionTerminateAllSessions action(ActionEnum action) {

        this.action = action;
        return this;
    }

    /**
     * This action revokes or terminates all of the user&#39;s active sessions.
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "This action revokes or terminates all of the user's active sessions.")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ActionEnum getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(ActionEnum action) {
        this.action = action;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntityRiskPolicyRuleActionTerminateAllSessions entityRiskPolicyRuleActionTerminateAllSessions = (EntityRiskPolicyRuleActionTerminateAllSessions) o;
        return Objects.equals(this.action, entityRiskPolicyRuleActionTerminateAllSessions.action);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(action);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntityRiskPolicyRuleActionTerminateAllSessions {\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/EntityRiskPolicyRuleActionTerminateAllSessions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EntityRiskPolicyRuleActionTerminateAllSessions
 */
@JsonPropertyOrder({ EntityRiskPolicyRuleActionTerminateAllSessions.JSON_PROPERTY_ACTION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class EntityRiskPolicyRuleActionTerminateAllSessions implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * This action revokes or terminates all of the user&#39;s active sessions.
     */
    public enum ActionEnum {
        TERMINATE_ALL_SESSIONS(String.valueOf("TERMINATE_ALL_SESSIONS")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        ActionEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static ActionEnum fromValue(String value) {
            for (ActionEnum b : ActionEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ACTION = "action";
    private ActionEnum action;

    public EntityRiskPolicyRuleActionTerminateAllSessions() {
    }

    public EntityRiskPolicyRuleActionTerminateAllSessions action(ActionEnum action) {

        this.action = action;
        return this;
    }

    /**
     * This action revokes or terminates all of the user&#39;s active sessions.
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "This action revokes or terminates all of the user's active sessions.")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ActionEnum getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(ActionEnum action) {
        this.action = action;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntityRiskPolicyRuleActionTerminateAllSessions entityRiskPolicyRuleActionTerminateAllSessions = (EntityRiskPolicyRuleActionTerminateAllSessions) o;
        return Objects.equals(this.action, entityRiskPolicyRuleActionTerminateAllSessions.action);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(action);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntityRiskPolicyRuleActionTerminateAllSessions {\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
